==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebTabComponentEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTabDescriptionMetadata } from "./WebTabDescriptionMetadata";
import { WebTabComponentEventArgsDescription } from "./WebTabComponentEventArgsDescription";
/**
 * @hidden
 */
var WebTabComponentEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebTabComponentEventArgsDescriptionMetadata, _super);
    function WebTabComponentEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebTabComponentEventArgsDescriptionMetadata.b = function (a) {
        if (WebTabComponentEventArgsDescriptionMetadata.a == null) {
            WebTabComponentEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebTabComponentEventArgsDescriptionMetadata.c(WebTabComponentEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebTabComponentEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebTabComponentEventArgsDescriptionMetadata.a);
        WebTabDescriptionMetadata.d(a);
    };
    WebTabComponentEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:TabComponentEventArgs");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Detail", "ExportedType:WebTab");
    };
    WebTabComponentEventArgsDescriptionMetadata.d = function (a) {
        WebTabComponentEventArgsDescriptionMetadata.b(a);
        a.ac("WebTabComponentEventArgs", function () { return new WebTabComponentEventArgsDescription(); });
        a.ab("WebTabComponentEventArgs", WebTabComponentEventArgsDescriptionMetadata.a);
    };
    WebTabComponentEventArgsDescriptionMetadata.$t = markType(WebTabComponentEventArgsDescriptionMetadata, 'WebTabComponentEventArgsDescriptionMetadata');
    WebTabComponentEventArgsDescriptionMetadata.a = null;
    return WebTabComponentEventArgsDescriptionMetadata;
}(Base));
export { WebTabComponentEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebTabComponentEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTabDescriptionMetadata } from "./WebTabDescriptionMetadata";
import { WebTabComponentEventArgsDescription } from "./WebTabComponentEventArgsDescription";
/**
 * @hidden
 */
var WebTabComponentEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebTabComponentEventArgsDescriptionMetadata, _super);
    function WebTabComponentEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebTabComponentEventArgsDescriptionMetadata.b = function (a) {
        if (WebTabComponentEventArgsDescriptionMetadata.a == null) {
            WebTabComponentEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebTabComponentEventArgsDescriptionMetadata.c(WebTabComponentEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebTabComponentEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebTabComponentEventArgsDescriptionMetadata.a);
        WebTabDescriptionMetadata.d(a);
    };
    WebTabComponentEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:TabComponentEventArgs");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__marshalByValue", "Boolean");
        a.item("Detail", "ExportedType:WebTab");
    };
    WebTabComponentEventArgsDescriptionMetadata.d = function (a) {
        WebTabComponentEventArgsDescriptionMetadata.b(a);
        a.ae("WebTabComponentEventArgs", function () { return new WebTabComponentEventArgsDescription(); });
        a.ad("WebTabComponentEventArgs", WebTabComponentEventArgsDescriptionMetadata.a);
    };
    WebTabComponentEventArgsDescriptionMetadata.$t = markType(WebTabComponentEventArgsDescriptionMetadata, 'WebTabComponentEventArgsDescriptionMetadata');
    WebTabComponentEventArgsDescriptionMetadata.a = null;
    return WebTabComponentEventArgsDescriptionMetadata;
}(Base));
export { WebTabComponentEventArgsDescriptionMetadata };
